@@ -2,7 +2,7 @@ from django.contrib.sitemaps import Sitemap
 from newscenter.models import Newsroom, Article
 
 
-class Newsroom(Sitemap):
+class NewsroomSitemap(Sitemap):
     def items(self):
         return Newsroom.objects.all()
 
